pub fn verify_commitment_link(
previous_commitment: &Commitment,
current_commitment: &Commitment,
) -> Result<(), ChainError>Expand description
Computes the expected hash of the previous commitment given a commitment.
This is a helper to verify that a commitment correctly references its predecessor.