MintProvider

Trait MintProvider 

pub trait MintProvider {
    // Required method
    fn mint_right(
        &self,
        proof: &CrossChainTransferProof,
    ) -> Result<CrossChainTransferResult, CrossChainError>;
}
Trait for minting a Right on a destination chain.

Required Methods

fn mint_right( &self, proof: &CrossChainTransferProof, ) -> Result<CrossChainTransferResult, CrossChainError>

Mint a new Right from a verified cross-chain transfer proof.

Creates a new Right with the same commitment and state but a new seal on the destination chain.

Implementors