Schema: contract logic definition and transition rules
A schema defines the valid state types, transition definitions, and validation rules for a class of contracts. It is the “class” in the OOP analogy — contracts are “instances” of schemas.
Structs
- Global
State Type - Definition of a global state type in the schema
- Owned
State Type - Definition of an owned state type in the schema
- Schema
- Contract schema
- Transition
Def - Transition definition in the schema
Enums
- Schema
Error - Schema validation errors
- State
Data Type - Data type for state values in the schema
- Transition
Validation Error - Transition validation errors
Constants
- SCHEMA_
VERSION - Schema version