pub struct VMInputs {
pub owned_inputs: Vec<OwnedState>,
pub global_state: Vec<GlobalState>,
pub metadata: Vec<Metadata>,
pub seal_data: Vec<u8>,
}Expand description
Input state for VM execution
Contains all state that must be consumed as input to a transition, including owned states, global state, metadata, and seal data.
Fields
owned_inputs: Vec<OwnedState>Owned states being consumed (resolved from StateRef)
global_state: Vec<GlobalState>Current global state values
metadata: Vec<Metadata>Transition metadata
seal_data: Vec<u8>Seal data being consumed (authorizes this transition)
Implementations
Sourceimpl VMInputs
impl VMInputs
Sourcepub fn new(
owned_inputs: Vec<OwnedState>,
global_state: Vec<GlobalState>,
metadata: Vec<Metadata>,
seal_data: Vec<u8>,
) -> Self
pub fn new( owned_inputs: Vec<OwnedState>, global_state: Vec<GlobalState>, metadata: Vec<Metadata>, seal_data: Vec<u8>, ) -> Self
Create new VM inputs
Sourcepub fn global_state_of(&self, type_id: StateTypeId) -> Vec<&GlobalState>
pub fn global_state_of(&self, type_id: StateTypeId) -> Vec<&GlobalState>
Look up a global state by type ID
Sourcepub fn owned_state_of(&self, type_id: StateTypeId) -> Vec<&OwnedState>
pub fn owned_state_of(&self, type_id: StateTypeId) -> Vec<&OwnedState>
Look up owned states by type ID