pub trait MintProvider {
// Required method
fn mint_right(
&self,
proof: &CrossChainTransferProof,
) -> Result<CrossChainTransferResult, CrossChainError>;
}Expand description
Trait for minting a Right on a destination chain.
Required Methods
Sourcefn mint_right(
&self,
proof: &CrossChainTransferProof,
) -> Result<CrossChainTransferResult, CrossChainError>
fn mint_right( &self, proof: &CrossChainTransferProof, ) -> Result<CrossChainTransferResult, CrossChainError>
Mint a new Right from a verified cross-chain transfer proof.
Creates a new Right with the same commitment and state but a new seal on the destination chain.