Module schema

Module schema 

Schema: contract logic definition and transition rules

A schema defines the valid state types, transition definitions, and validation rules for a class of contracts. It is the “class” in the OOP analogy — contracts are “instances” of schemas.

Structs

GlobalStateType
Definition of a global state type in the schema
OwnedStateType
Definition of an owned state type in the schema
Schema
Contract schema
TransitionDef
Transition definition in the schema

Enums

SchemaError
Schema validation errors
StateDataType
Data type for state values in the schema
TransitionValidationError
Transition validation errors

Constants

SCHEMA_VERSION
Schema version